@@ -94,7 +94,7 @@ class CommonMethods(MethodsInterface):
                 except (OSError, IndexError):
                     pass
             if (self.clVars.Get('cl_autoupdate_set') == 'on' or
-                    origdata == newdata):
+                        origdata == newdata):
                 answ = "use new"
             else:
                 orig_content = normalize_config(readFile(orig))
@@ -660,8 +660,8 @@ class Action(MethodsInterface):
                             elif message:
                                 # если действие с командой
                                 if ("error" not in action and
-                                        "method" in action or
-                                        "command" in action):
+                                            "method" in action or
+                                            "command" in action):
                                     self.startTask(str(message))
                                     task = True
                                 # действие содержит только сообщение
@@ -787,12 +787,16 @@ def catchExcept(*skipException):
                 from calculate.core.server.api_types import ViewInfo, \
                     GroupField, Field
 
+                if isinstance(e, KeyboardInterrupt):
+                    error = _("Task interrupted")
+                else:
+                    error = str(e)
                 view = ViewInfo(groups=[])
                 group = GroupField(name=_("Error"), last=True)
                 group.fields = []
                 group.fields.append(Field(
                     name="error",
-                    label=str(e),
+                    label=error,
                     default='color:red;',
                     element="error"))
                 view.groups.append(group)
@@ -830,7 +834,7 @@ def shortTraceback(e1, e2, e3):
     return "%s:%s(%s:%s)" % (e1.__name__, str(e2), modname, frame.tb_lineno)
 
 
-class ActiveClientStatus:
+class ActiveClientStatus(object):
     Success = 0
     Failed = 1
     WrongSID = 2
@@ -850,7 +854,7 @@ class CoreWsdl(CoreServiceInterface):
                     return ActiveClientStatus.Failed
                 # check sid in sid.db
                 if not (os.path.isfile(self.sids_file) and
-                        self.find_sid_in_file(sid)):
+                            self.find_sid_in_file(sid)):
                     try:
                         os.unlink(sid_file)
                     except (OSError, IOError):
@@ -913,8 +917,7 @@ class CoreWsdl(CoreServiceInterface):
 
         results = []
         for item in LoadedMethods.conMethods:
-            temp = []
-            temp.append(item)
+            temp = [item]
             for i in LoadedMethods.conMethods[item]:
                 temp.append(i)
             results.append(temp)
@@ -927,8 +930,7 @@ class CoreWsdl(CoreServiceInterface):
         results = []
         for item in LoadedMethods.guiMethods:
             for i in range(0, len(LoadedMethods.guiMethods[item]), 3):
-                temp = []
-                temp.append(item)
+                temp = [item]
                 for j in range(3):
                     temp.append(LoadedMethods.guiMethods[item][i + j])
                 results.append(temp)
@@ -1241,7 +1243,7 @@ class CoreWsdl(CoreServiceInterface):
     def target_helper(self, com, target_proc, method_name, *args_proc):
         if not os.path.exists(self.pids):
             os.system('mkdir %s' % self.pids)
-        #        PID_FILE  =  self.pids + '/%d.pid'%com.pid
+        # PID_FILE  =  self.pids + '/%d.pid'%com.pid
         import datetime
 
         dat = datetime.datetime.now()
@@ -1468,9 +1470,9 @@ def create_symlink(data_path, old_data_path):
     for line in readLinesFile(symlinks_file):
         cmdname = os.path.basename(line)
         if (cmdname not in meths.keys() or
-                line.startswith(path_to_link) and meths[cmdname][1] or
-                line.startswith(path_to_user_link) and
-                not meths[cmdname][1]):
+                    line.startswith(path_to_link) and meths[cmdname][1] or
+                    line.startswith(path_to_user_link) and
+                    not meths[cmdname][1]):
             if os.path.islink(line):
                 os.unlink(line)
                 print _('Symlink %s deleted') % line
@@ -1534,25 +1536,25 @@ class WsdlMeta(type):
     def __new__(mcs, name, bases, attrs):
         if "methods" in attrs:
             for method in attrs["methods"]:
-                attrs[method['method_name']] = mcs.callerConstructor(**method)
+                attrs[method['method_name']] = mcs.caller_constructor(**method)
                 attrs["%s_vars" % method[
-                    'method_name']] = mcs.datavarsConstructor(**method)
-                attrs["%s_view" % method['method_name']] = mcs.viewConstructor(
-                    **method)
+                    'method_name']] = mcs.datavars_constructor(**method)
+                attrs["%s_view"
+                      % method['method_name']] = mcs.view_constructor(**method)
         return type.__new__(mcs, name, bases, attrs)
 
     @classmethod
-    def closeDataVars(mcs):
+    def close_datavars(mcs):
         for dv in WsdlMeta.datavars.values():
             dv.close()
 
     @classmethod
-    def createInfoObj(mcs, **kwargs):
+    def create_info_obj(mcs, **kwargs):
         """
         Создание передаваемой структуры данных для WSDL
         """
 
-        def typeConvert(s):
+        def type_convert(s):
             if "bool" in s:
                 return Boolean
             elif "table" in s:
@@ -1575,7 +1577,7 @@ class WsdlMeta(type):
         def group(*args, **kwargs):
             for v in chain(kwargs.get('normal', ()), kwargs.get('expert', ())):
                 varname = v.rpartition(".")[2]
-                d[varname] = typeConvert(dv.getInfo(v).type)
+                d[varname] = type_convert(dv.getInfo(v).type)
 
         for gr in kwargs['groups']:
             gr(group)
@@ -1585,20 +1587,20 @@ class WsdlMeta(type):
         return d
 
     @classmethod
-    def callerConstructor(mcs, **kwargs):
+    def caller_constructor(mcs, **kwargs):
         """
         Конструктор для создания метода-вызова для действия
         """
 
         def wrapper(self, sid, info):
             # костыль для локализации install
-            callbackRefresh = (
+            callback_refresh = (
                 self.fixInstallLocalization
                 if kwargs['method_name'] == 'install' else lambda dv, sid: True)
             return self.callAction(sid, info, logicClass=kwargs['logic'],
                                    actionClass=kwargs['action'],
                                    method_name=kwargs['method_name'],
-                                   callbackRefresh=callbackRefresh)
+                                   callbackRefresh=callback_refresh)
 
         wrapper.func_name = kwargs['method_name']
         func = LoadedMethods.core_method(category=kwargs.get('category', None),
@@ -1609,7 +1611,7 @@ class WsdlMeta(type):
                                          command=kwargs.get('command', None),
                                          rights=kwargs['rights'])(wrapper)
         if "--start" in sys.argv:
-            info_obj = mcs.createInfoObj(**kwargs)
+            info_obj = mcs.create_info_obj(**kwargs)
             info_class = type("%sInfo" % kwargs["method_name"], (CommonInfo,),
                               info_obj)
             return rpc(Integer, info_class,
@@ -1618,7 +1620,7 @@ class WsdlMeta(type):
             return func
 
     @classmethod
-    def modifyDatavars(mcs, dv, data):
+    def modify_datavars(mcs, dv, data):
         """
         Поменять значения в datavars согласно data
         """
@@ -1630,7 +1632,7 @@ class WsdlMeta(type):
             dv.Set(k.strip('!'), v, force=k.endswith('!'))
 
     @classmethod
-    def viewConstructor(mcs, **kwargs):
+    def view_constructor(mcs, **kwargs):
         """
         Конструктор для создания метода-представления
         """
@@ -1651,9 +1653,9 @@ class WsdlMeta(type):
                 dv = getattr(self, "%s_vars" % kwargs["method_name"])()
                 if hasattr(params, "clienttype"):
                     if params.clienttype == 'gui' and "guivars" in kwargs:
-                        mcs.modifyDatavars(dv, kwargs['guivars'])
+                        mcs.modify_datavars(dv, kwargs['guivars'])
                     if params.clienttype != 'gui' and "consolevars" in kwargs:
-                        mcs.modifyDatavars(dv, kwargs['consolevars'])
+                        mcs.modify_datavars(dv, kwargs['consolevars'])
             else:
                 # костыль для метода install, который меняет локализацию
                 # интрефейса в зависимости от выбранного параметра lang
@@ -1681,7 +1683,7 @@ class WsdlMeta(type):
             catchExcept(kwargs.get("native_error", ()))(wrapper))
 
     @classmethod
-    def datavarsConstructor(mcs, **kwargs):
+    def datavars_constructor(mcs, **kwargs):
         """
         Конструктор для создания метода описания параметров
         """
@@ -1694,7 +1696,7 @@ class WsdlMeta(type):
                     'calculate.%s.variables' % kwargs['datavars'])
                 dv.defaultModule = kwargs['datavars']
                 dv.flIniFile()
-                mcs.modifyDatavars(dv, kwargs['setvars'])
+                mcs.modify_datavars(dv, kwargs['setvars'])
             # созданием группы переменных из datavars согласно параметрам groups
             for groupfunc in kwargs['groups']:
                 groupfunc(dv.addGroup)
@@ -1720,6 +1722,6 @@ def clearDataVars(func):
         try:
             return func(*args, **kwargs)
         finally:
-            WsdlMeta.closeDataVars()
+            WsdlMeta.close_datavars()
 
     return wrapper
